@@ -52,7 +52,8 @@ print.profileCI <- function(x, ...) {
 #'   indicating the values of these limits and a legend stating the
 #'   confidence interval.
 #' @param digits An integer. Passed to [`signif`] to round the confidence
-#'   limits in the legend, if `add = TRUE`.
+#'   limits in the legend, if `add = TRUE`. The confidence level is hard-coded
+#'   to be expressed to 3 significant figures.
 #' @rdname profileCI_methods
 #' @export
 plot.profileCI <- function(x, parm = 1:nrow(x), add = TRUE, digits = 2, ...) {
@@ -93,7 +94,8 @@ plot.profileCI <- function(x, parm = 1:nrow(x), add = TRUE, digits = 2, ...) {
     graphics::abline(v = limits, lty = 2)
     level <- attr(x, "level") * 100
     rlimits <- signif(limits, digits)
-    legend_text <- paste0(level, "% CI: (", rlimits[1], ",", rlimits[2], ")")
+    legend_text <- paste0(signif(level, 3), "% CI: (", rlimits[1], ",",
+                          rlimits[2], ")")
     graphics::legend("bottom", legend = legend_text)
   }
   return(invisible(limits))
