@@ -6,7 +6,10 @@
 #' generic.
 #'
 #' @param object A fitted model object. This object must have a `coef` S3
-#'   method. If `faster = TRUE` then it must also have a `vcov` S3 method.
+#'   method that returns a **named** vector of parameter values. If
+#'   `faster = TRUE` or `profile = FALSE` then it must also have a `vcov` S3
+#'   method that returns a matrix with `dimnames` that match those in the
+#'   vector returned by the `coef` method.
 #'   If necessary, these may be created using [`.S3method()`]. For example, if
 #'   `object` is a list inheriting from class `"foo"`, with coefficients
 #'   in `object$coefficients` and variance-covariance matrix in `object$vcov`,
@@ -37,8 +40,10 @@
 #'   standard error of the estimator of the parameter. Decreasing `mult`
 #'   profiles at more points but will be slower.
 #' @param faster A logical scalar. If `faster = TRUE` then the profiling of the
-#'   log-likelihood is in search of a lower (upper) confidence limit is
+#'   log-likelihood in search of a lower (upper) confidence limit is
 #'   started at the corresponding symmetric lower (upper) confidence limit.
+#'   However, `faster = FALSE` is more robust, particularly if a symmetric
+#'   limit is close to, or beyond, the edge of the parameter space.
 #' @param epsilon Only relevant if `profile = TRUE`. A numeric vector of values
 #'   that determine the accuracy of the confidence limits. `epsilon` is
 #'   recycled to the length of the parameter vector `parm`.
@@ -49,8 +54,9 @@
 #'     that defines the confidence limits, once profiling has been successful
 #'     in finding an interval within which this value lies.
 #'
-#'    * If `epsilon[i] < 0` quadratic interpolation is used, which will tend to
-#'      be faster.
+#'    * If `epsilon[i] < 0` monotonic cubic spline interpolation
+#'      ([`stats::splinefun`] with `method = "hyman")` is used, which will tend
+#'      to be faster.
 #'
 #'   * If `epsilon[i] = 0` then linear interpolation is used, which will be
 #'     faster still.
@@ -170,7 +176,7 @@ profileCI <- function(object, loglik, ..., parm = "all", level = 0.95,
   # Check and set parm
   cf <- coef(object)
   if (is.null(names(cf))) {
-    names(cf) <- paste0("par", 1:length(cf))
+    stop("The parameters in coef(object) must be named.")
   }
   parm_names <- names(cf)
   if (is.character(parm)) {
@@ -222,6 +228,14 @@ profileCI <- function(object, loglik, ..., parm = "all", level = 0.95,
   # If profile = FALSE then we return these
   # If faster = TRUE then we pass these intervals to faster_profile_ci()
   if (!profile | faster) {
+    # Check that dimnames exist and match those in coef(object)
+    vnames <- dimnames(vcov(object))
+    if (is.null(vnames)) {
+      stop("The dimensions of vcov(object) must be named.")
+    }
+    if (any(vnames[[1]] != parm_names) || any(vnames[[2]] != parm_names)) {
+      stop("dimnames(vcov(object)) must match names(coef(object))")
+    }
     z_val <- stats::qnorm(1 - (1 - level) / 2)
     mles <- coef(object)[parm]
     ses <- sqrt(diag(vcov(object)))[parm]
@@ -233,6 +247,17 @@ profileCI <- function(object, loglik, ..., parm = "all", level = 0.95,
     up <- paste0(100 - 100 * (1 - level)/ 2, "%")
     colnames(ci_mat) <- c(low, up)
     ci_sym_mat <- ci_mat
+    # If lb and/or ub have been supplied then constrain the values in ci_sym_mat
+    # in light of this. This prevents the search for the profile interval
+    # starting outside the parameter range of the parameter of interest.
+    # Move in 10% of the distance from the bound to the MLE
+    propn <- 0.1
+    if (any(is.finite(lb))) {
+      ci_sym_mat[, 1] <- pmax(ci_sym_mat[, 1], lb + propn * (cf[parm] - lb))
+    }
+    if (any(is.finite(ub))) {
+      ci_sym_mat[, 2] <- pmin(ci_sym_mat[, 2], ub - propn * (ub - cf[parm]))
+    }
   } else {
     ci_mat <- matrix(NA, ncol = 2, nrow = length(parm))
   }
@@ -244,7 +269,6 @@ profileCI <- function(object, loglik, ..., parm = "all", level = 0.95,
     class(ci_mat) <- c("profileCI", "matrix", "array")
     return(ci_mat)
   }
-
   # The number of parameters
   n_parm <- length(parm)
   # Force epsilon to have length equal to the number of parameters
